import Long from "long";
import _m0 from "protobufjs/minimal";
import { Coin } from "../../../cosmos/base/v1beta1/coin";
import { CDP, Deposit } from "./cdp";
export declare const protobufPackage = "kava.cdp.v1beta1";
/** GenesisState defines the cdp module's genesis state. */
export interface GenesisState {
    /** params defines all the paramaters of the module. */
    params?: Params | undefined;
    cdps: CDP[];
    deposits: Deposit[];
    startingCdpId: Long;
    debtDenom: string;
    govDenom: string;
    previousAccumulationTimes: GenesisAccumulationTime[];
    totalPrincipals: GenesisTotalPrincipal[];
}
/** Params defines the parameters for the cdp module. */
export interface Params {
    collateralParams: CollateralParam[];
    debtParam?: DebtParam | undefined;
    globalDebtLimit?: Coin | undefined;
    surplusAuctionThreshold: string;
    surplusAuctionLot: string;
    debtAuctionThreshold: string;
    debtAuctionLot: string;
    circuitBreaker: boolean;
}
/** DebtParam defines governance params for debt assets */
export interface DebtParam {
    denom: string;
    referenceAsset: string;
    conversionFactor: string;
    debtFloor: string;
}
/** CollateralParam defines governance parameters for each collateral type within the cdp module */
export interface CollateralParam {
    denom: string;
    type: string;
    liquidationRatio: string;
    debtLimit?: Coin | undefined;
    stabilityFee: string;
    auctionSize: string;
    liquidationPenalty: string;
    spotMarketId: string;
    liquidationMarketId: string;
    keeperRewardPercentage: string;
    checkCollateralizationIndexCount: string;
    conversionFactor: string;
}
/** GenesisAccumulationTime defines the previous distribution time and its corresponding denom */
export interface GenesisAccumulationTime {
    collateralType: string;
    previousAccumulationTime?: Date | undefined;
    interestFactor: string;
}
/** GenesisTotalPrincipal defines the total principal and its corresponding collateral type */
export interface GenesisTotalPrincipal {
    collateralType: string;
    totalPrincipal: string;
}
export declare const GenesisState: {
    encode(message: GenesisState, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GenesisState;
    fromJSON(object: any): GenesisState;
    toJSON(message: GenesisState): unknown;
    create(base?: DeepPartial<GenesisState>): GenesisState;
    fromPartial(object: DeepPartial<GenesisState>): GenesisState;
};
export declare const Params: {
    encode(message: Params, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): Params;
    fromJSON(object: any): Params;
    toJSON(message: Params): unknown;
    create(base?: DeepPartial<Params>): Params;
    fromPartial(object: DeepPartial<Params>): Params;
};
export declare const DebtParam: {
    encode(message: DebtParam, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): DebtParam;
    fromJSON(object: any): DebtParam;
    toJSON(message: DebtParam): unknown;
    create(base?: DeepPartial<DebtParam>): DebtParam;
    fromPartial(object: DeepPartial<DebtParam>): DebtParam;
};
export declare const CollateralParam: {
    encode(message: CollateralParam, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): CollateralParam;
    fromJSON(object: any): CollateralParam;
    toJSON(message: CollateralParam): unknown;
    create(base?: DeepPartial<CollateralParam>): CollateralParam;
    fromPartial(object: DeepPartial<CollateralParam>): CollateralParam;
};
export declare const GenesisAccumulationTime: {
    encode(message: GenesisAccumulationTime, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GenesisAccumulationTime;
    fromJSON(object: any): GenesisAccumulationTime;
    toJSON(message: GenesisAccumulationTime): unknown;
    create(base?: DeepPartial<GenesisAccumulationTime>): GenesisAccumulationTime;
    fromPartial(object: DeepPartial<GenesisAccumulationTime>): GenesisAccumulationTime;
};
export declare const GenesisTotalPrincipal: {
    encode(message: GenesisTotalPrincipal, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GenesisTotalPrincipal;
    fromJSON(object: any): GenesisTotalPrincipal;
    toJSON(message: GenesisTotalPrincipal): unknown;
    create(base?: DeepPartial<GenesisTotalPrincipal>): GenesisTotalPrincipal;
    fromPartial(object: DeepPartial<GenesisTotalPrincipal>): GenesisTotalPrincipal;
};
type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
export type DeepPartial<T> = T extends Builtin ? T : T extends Long ? string | number | Long : T extends globalThis.Array<infer U> ? globalThis.Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
export {};
