import Long from "long";
import _m0 from "protobufjs/minimal";
import { StrategyType } from "./strategy";
export declare const protobufPackage = "kava.earn.v1beta1";
/**
 * AllowedVault is a vault that is allowed to be created. These can be
 * modified via parameter governance.
 */
export interface AllowedVault {
    /** Denom is the only supported denomination of the vault for deposits and withdrawals. */
    denom: string;
    /** VaultStrategy is the strategy used for this vault. */
    strategies: StrategyType[];
    /**
     * IsPrivateVault is true if the vault only allows depositors contained in
     * AllowedDepositors.
     */
    isPrivateVault: boolean;
    /**
     * AllowedDepositors is a list of addresses that are allowed to deposit to
     * this vault if IsPrivateVault is true. Addresses not contained in this list
     * are not allowed to deposit into this vault. If IsPrivateVault is false,
     * this should be empty and ignored.
     */
    allowedDepositors: Uint8Array[];
}
/** VaultRecord is the state of a vault. */
export interface VaultRecord {
    /** TotalShares is the total distributed number of shares in the vault. */
    totalShares?: VaultShare | undefined;
}
/** VaultShareRecord defines the vault shares owned by a depositor. */
export interface VaultShareRecord {
    /** Depositor represents the owner of the shares */
    depositor: Uint8Array;
    /** Shares represent the vault shares owned by the depositor. */
    shares: VaultShare[];
}
/** VaultShare defines shares of a vault owned by a depositor. */
export interface VaultShare {
    denom: string;
    amount: string;
}
export declare const AllowedVault: {
    encode(message: AllowedVault, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): AllowedVault;
    fromJSON(object: any): AllowedVault;
    toJSON(message: AllowedVault): unknown;
    create(base?: DeepPartial<AllowedVault>): AllowedVault;
    fromPartial(object: DeepPartial<AllowedVault>): AllowedVault;
};
export declare const VaultRecord: {
    encode(message: VaultRecord, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): VaultRecord;
    fromJSON(object: any): VaultRecord;
    toJSON(message: VaultRecord): unknown;
    create(base?: DeepPartial<VaultRecord>): VaultRecord;
    fromPartial(object: DeepPartial<VaultRecord>): VaultRecord;
};
export declare const VaultShareRecord: {
    encode(message: VaultShareRecord, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): VaultShareRecord;
    fromJSON(object: any): VaultShareRecord;
    toJSON(message: VaultShareRecord): unknown;
    create(base?: DeepPartial<VaultShareRecord>): VaultShareRecord;
    fromPartial(object: DeepPartial<VaultShareRecord>): VaultShareRecord;
};
export declare const VaultShare: {
    encode(message: VaultShare, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): VaultShare;
    fromJSON(object: any): VaultShare;
    toJSON(message: VaultShare): unknown;
    create(base?: DeepPartial<VaultShare>): VaultShare;
    fromPartial(object: DeepPartial<VaultShare>): VaultShare;
};
type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
export type DeepPartial<T> = T extends Builtin ? T : T extends Long ? string | number | Long : T extends globalThis.Array<infer U> ? globalThis.Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
export {};
