import Long from "long";
import _m0 from "protobufjs/minimal";
import { Coin } from "../../../cosmos/base/v1beta1/coin";
export declare const protobufPackage = "kava.kavadist.v1beta1";
/** Params governance parameters for kavadist module */
export interface Params {
    active: boolean;
    periods: Period[];
    infrastructureParams?: InfrastructureParams | undefined;
}
/** InfrastructureParams define the parameters for infrastructure rewards. */
export interface InfrastructureParams {
    infrastructurePeriods: Period[];
    coreRewards: CoreReward[];
    partnerRewards: PartnerReward[];
}
/** CoreReward defines the reward weights for core infrastructure providers. */
export interface CoreReward {
    address: Uint8Array;
    weight: string;
}
/** PartnerRewards defines the reward schedule for partner infrastructure providers. */
export interface PartnerReward {
    address: Uint8Array;
    rewardsPerSecond?: Coin | undefined;
}
/**
 * Period stores the specified start and end dates, and the inflation, expressed as a decimal
 * representing the yearly APR of KAVA tokens that will be minted during that period
 */
export interface Period {
    /** example "2020-03-01T15:20:00Z" */
    start?: Date | undefined;
    /** example "2020-06-01T15:20:00Z" */
    end?: Date | undefined;
    /** example "1.000000003022265980"  - 10% inflation */
    inflation: Uint8Array;
}
export declare const Params: {
    encode(message: Params, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): Params;
    fromJSON(object: any): Params;
    toJSON(message: Params): unknown;
    create(base?: DeepPartial<Params>): Params;
    fromPartial(object: DeepPartial<Params>): Params;
};
export declare const InfrastructureParams: {
    encode(message: InfrastructureParams, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): InfrastructureParams;
    fromJSON(object: any): InfrastructureParams;
    toJSON(message: InfrastructureParams): unknown;
    create(base?: DeepPartial<InfrastructureParams>): InfrastructureParams;
    fromPartial(object: DeepPartial<InfrastructureParams>): InfrastructureParams;
};
export declare const CoreReward: {
    encode(message: CoreReward, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): CoreReward;
    fromJSON(object: any): CoreReward;
    toJSON(message: CoreReward): unknown;
    create(base?: DeepPartial<CoreReward>): CoreReward;
    fromPartial(object: DeepPartial<CoreReward>): CoreReward;
};
export declare const PartnerReward: {
    encode(message: PartnerReward, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): PartnerReward;
    fromJSON(object: any): PartnerReward;
    toJSON(message: PartnerReward): unknown;
    create(base?: DeepPartial<PartnerReward>): PartnerReward;
    fromPartial(object: DeepPartial<PartnerReward>): PartnerReward;
};
export declare const Period: {
    encode(message: Period, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): Period;
    fromJSON(object: any): Period;
    toJSON(message: Period): unknown;
    create(base?: DeepPartial<Period>): Period;
    fromPartial(object: DeepPartial<Period>): Period;
};
type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
export type DeepPartial<T> = T extends Builtin ? T : T extends Long ? string | number | Long : T extends globalThis.Array<infer U> ? globalThis.Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
export {};
