import Long from "long";
import _m0 from "protobufjs/minimal";
import { PageRequest, PageResponse } from "../../../cosmos/base/query/v1beta1/pagination";
import { Coin } from "../../../cosmos/base/v1beta1/coin";
import { Params } from "./swap";
export declare const protobufPackage = "kava.swap.v1beta1";
/** QueryParamsRequest defines the request type for querying x/swap parameters. */
export interface QueryParamsRequest {
}
/** QueryParamsResponse defines the response type for querying x/swap parameters. */
export interface QueryParamsResponse {
    /** params represents the swap module parameters */
    params?: Params | undefined;
}
/** QueryPoolsRequest is the request type for the Query/Pools RPC method. */
export interface QueryPoolsRequest {
    /** pool_id filters pools by id */
    poolId: string;
    /** pagination defines an optional pagination for the request. */
    pagination?: PageRequest | undefined;
}
/** QueryPoolsResponse is the response type for the Query/Pools RPC method. */
export interface QueryPoolsResponse {
    /** pools represents returned pools */
    pools: PoolResponse[];
    /** pagination defines the pagination in the response. */
    pagination?: PageResponse | undefined;
}
/** Pool represents the state of a single pool */
export interface PoolResponse {
    /** name represents the name of the pool */
    name: string;
    /** coins represents the total reserves of the pool */
    coins: Coin[];
    /** total_shares represents the total shares of the pool */
    totalShares: string;
}
/** QueryDepositsRequest is the request type for the Query/Deposits RPC method. */
export interface QueryDepositsRequest {
    /** owner optionally filters deposits by owner */
    owner: string;
    /** pool_id optionally fitlers deposits by pool id */
    poolId: string;
    /** pagination defines an optional pagination for the request. */
    pagination?: PageRequest | undefined;
}
/** QueryDepositsResponse is the response type for the Query/Deposits RPC method. */
export interface QueryDepositsResponse {
    /** deposits returns the deposits matching the requested parameters */
    deposits: DepositResponse[];
    /** pagination defines the pagination in the response. */
    pagination?: PageResponse | undefined;
}
/** DepositResponse defines a single deposit query response type. */
export interface DepositResponse {
    /** depositor represents the owner of the deposit */
    depositor: string;
    /** pool_id represents the pool the deposit is for */
    poolId: string;
    /** shares_owned presents the shares owned by the depositor for the pool */
    sharesOwned: string;
    /** shares_value represents the coin value of the shares_owned */
    sharesValue: Coin[];
}
export declare const QueryParamsRequest: {
    encode(_: QueryParamsRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryParamsRequest;
    fromJSON(_: any): QueryParamsRequest;
    toJSON(_: QueryParamsRequest): unknown;
    create(base?: DeepPartial<QueryParamsRequest>): QueryParamsRequest;
    fromPartial(_: DeepPartial<QueryParamsRequest>): QueryParamsRequest;
};
export declare const QueryParamsResponse: {
    encode(message: QueryParamsResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryParamsResponse;
    fromJSON(object: any): QueryParamsResponse;
    toJSON(message: QueryParamsResponse): unknown;
    create(base?: DeepPartial<QueryParamsResponse>): QueryParamsResponse;
    fromPartial(object: DeepPartial<QueryParamsResponse>): QueryParamsResponse;
};
export declare const QueryPoolsRequest: {
    encode(message: QueryPoolsRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryPoolsRequest;
    fromJSON(object: any): QueryPoolsRequest;
    toJSON(message: QueryPoolsRequest): unknown;
    create(base?: DeepPartial<QueryPoolsRequest>): QueryPoolsRequest;
    fromPartial(object: DeepPartial<QueryPoolsRequest>): QueryPoolsRequest;
};
export declare const QueryPoolsResponse: {
    encode(message: QueryPoolsResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryPoolsResponse;
    fromJSON(object: any): QueryPoolsResponse;
    toJSON(message: QueryPoolsResponse): unknown;
    create(base?: DeepPartial<QueryPoolsResponse>): QueryPoolsResponse;
    fromPartial(object: DeepPartial<QueryPoolsResponse>): QueryPoolsResponse;
};
export declare const PoolResponse: {
    encode(message: PoolResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): PoolResponse;
    fromJSON(object: any): PoolResponse;
    toJSON(message: PoolResponse): unknown;
    create(base?: DeepPartial<PoolResponse>): PoolResponse;
    fromPartial(object: DeepPartial<PoolResponse>): PoolResponse;
};
export declare const QueryDepositsRequest: {
    encode(message: QueryDepositsRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryDepositsRequest;
    fromJSON(object: any): QueryDepositsRequest;
    toJSON(message: QueryDepositsRequest): unknown;
    create(base?: DeepPartial<QueryDepositsRequest>): QueryDepositsRequest;
    fromPartial(object: DeepPartial<QueryDepositsRequest>): QueryDepositsRequest;
};
export declare const QueryDepositsResponse: {
    encode(message: QueryDepositsResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): QueryDepositsResponse;
    fromJSON(object: any): QueryDepositsResponse;
    toJSON(message: QueryDepositsResponse): unknown;
    create(base?: DeepPartial<QueryDepositsResponse>): QueryDepositsResponse;
    fromPartial(object: DeepPartial<QueryDepositsResponse>): QueryDepositsResponse;
};
export declare const DepositResponse: {
    encode(message: DepositResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): DepositResponse;
    fromJSON(object: any): DepositResponse;
    toJSON(message: DepositResponse): unknown;
    create(base?: DeepPartial<DepositResponse>): DepositResponse;
    fromPartial(object: DeepPartial<DepositResponse>): DepositResponse;
};
/** Query defines the gRPC querier service for swap module */
export interface Query {
    /** Params queries all parameters of the swap module. */
    Params(request: QueryParamsRequest): Promise<QueryParamsResponse>;
    /** Pools queries pools based on pool ID */
    Pools(request: QueryPoolsRequest): Promise<QueryPoolsResponse>;
    /** Deposits queries deposit details based on owner address and pool */
    Deposits(request: QueryDepositsRequest): Promise<QueryDepositsResponse>;
}
export declare const QueryServiceName = "kava.swap.v1beta1.Query";
export declare class QueryClientImpl implements Query {
    private readonly rpc;
    private readonly service;
    constructor(rpc: Rpc, opts?: {
        service?: string;
    });
    Params(request: QueryParamsRequest): Promise<QueryParamsResponse>;
    Pools(request: QueryPoolsRequest): Promise<QueryPoolsResponse>;
    Deposits(request: QueryDepositsRequest): Promise<QueryDepositsResponse>;
}
interface Rpc {
    request(service: string, method: string, data: Uint8Array): Promise<Uint8Array>;
}
type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
export type DeepPartial<T> = T extends Builtin ? T : T extends Long ? string | number | Long : T extends globalThis.Array<infer U> ? globalThis.Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
export {};
